@@ -20,7 +20,7 @@ tm1_get_cube_dimensions <- function(tm1_connection, cube) {
 
 
   # url development
-  url <- paste(u1, u2, u3, u4, u5, u6, u7, sep = "")
+  url <- paste0(u1, u2, u3, u4, u5, u6, u7)
   #url = "https://localhost:8881/api/v1/Cubes('SalesCube')/Dimensions"
 
   # post request
